@@ -132,7 +132,6 @@ def upload_to_cloud(report: RunOutput, debug=False) -> dict:
             'file_path': report.path
         }
 
-    # console.print(f'[[bold yellow]Skipped[/bold yellow]] Reason: {response.get("message")}')
     if debug:
         console.print(response)
     return {
@@ -152,6 +151,11 @@ class CloudConnector():
     def is_auto_upload() -> bool:
         return piperider_cloud.config.get('auto_upload', False)
 
+    @staticmethod
+    def config_auto_upload(flag: bool):
+        console.print(f'[[bold green]Config[/bold green]] Default auto upload behavior is set to {flag}')
+        piperider_cloud.update_config({'auto_upload': flag})
+
     @staticmethod
     def login(api_token=None, options: dict = None, debug=False):
 
