@@ -13,12 +13,13 @@ from rich.pretty import Pretty
 from rich.progress import Progress, Column, TextColumn, BarColumn, TimeElapsedColumn, MofNCompleteColumn
 from rich.style import Style
 from rich.table import Table
+from sqlalchemy import inspect
 from sqlalchemy.exc import NoSuchTableError
 
 from piperider_cli import convert_to_tzlocal, datetime_to_str, clone_directory, \
     raise_exception_when_directory_not_writable
 from piperider_cli import event
-from piperider_cli.adapter import DbtAdapter
+import piperider_cli.dbtutil as dbtutil
 from piperider_cli.assertion_engine import AssertionEngine
 from piperider_cli.assertion_engine.recommender import RECOMMENDED_ASSERTION_TAG
 from piperider_cli.configuration import Configuration
@@ -126,57 +127,12 @@ class RichProfilerEventHandler(ProfilerEventHandler):
         self.progress.update(task_id, advance=1)
 
 
-def _agreed_to_run_recommended_assertions(console: Console, interactive: bool):
-    if interactive:
-        console.print('Please press enter to continue ...',
-                      end=' ')
-        confirm = input('').strip().lower()
-        return confirm == 'yes' or confirm == 'y' or confirm == ''  # default yes
-    else:
-        return True
-
-
-def _agreed_to_generate_recommended_assertions(console: Console, interactive: bool, skip_recommend: bool):
-    if skip_recommend:
-        return False
-
-    if interactive:
-        console.print('Do you want to auto generate recommended assertions for this datasource \[Yes/no]?',
-                      end=' ')
-        confirm = input('').strip().lower()
-        return confirm == 'yes' or confirm == 'y' or confirm == ''  # default yes
-    else:
-        return True
-
-
-def _execute_assertions(console: Console, engine, ds_name: str, interaction: bool,
-                        output, profiler_result, created_at, skip_recommend: bool):
+def _execute_assertions(console: Console, engine, ds_name: str, output, profiler_result, created_at):
     # TODO: Implement running test cases based on profiling result
     assertion_engine = AssertionEngine(engine)
     assertion_engine.load_assertions(profiler_result)
-    assertion_exist = True if assertion_engine.assertions_content else False
 
     results = exceptions = []
-    if not assertion_exist:
-        console.print('[bold yellow]No assertion found[/]')
-        if _agreed_to_generate_recommended_assertions(console, interaction, skip_recommend):
-            # Generate recommended assertions
-            console.rule('Generating Recommended Assertions')
-            recommended_assertions = assertion_engine.generate_recommended_assertions(profiler_result)
-            for f in recommended_assertions:
-                console.print(f'[bold green]Recommended Assertion[/bold green]: {f}')
-            if _agreed_to_run_recommended_assertions(console, interaction):
-                assertion_engine.load_assertions(profiler_result)
-            else:
-                console.print(f'[[bold yellow]Skip[/bold yellow]] Executing assertion for datasource [ {ds_name} ]')
-                return [], []
-        else:
-            # Generate assertion templates
-            console.rule('Generating Assertion Templates')
-            template_assertions = assertion_engine.generate_template_assertions(profiler_result)
-            for f in template_assertions:
-                console.print(f'[bold green]Template Assertion[/bold green]: {f}')
-
     # Execute assertions
     if len(assertion_engine.assertions):
         console.rule('Testing')
@@ -501,7 +457,7 @@ def _append_descriptions_from_assertion(profile_result):
                     'description'] = f'{column_desc} - via PipeRider'
 
 
-def _analyse_and_log_run_event(profiled_result, assertion_results, dbt_test_results, dbt_command):
+def _analyse_and_log_run_event(profiled_result, assertion_results, dbt_test_results):
     tables = profiled_result.get('tables', [])
     event_payload = RunEventPayload()
     event_payload.tables = len(tables)
@@ -534,7 +490,6 @@ def _analyse_and_log_run_event(profiled_result, assertion_results, dbt_test_resu
             else:
                 event_payload.failed_dbt_testcases += 1
 
-    event_payload.dbt_command = dbt_command
     event.log_event(event_payload.to_dict(), 'run')
 
 
@@ -570,8 +525,8 @@ def _check_test_status(assertion_results, assertion_exceptions, dbt_test_results
 
 class Runner():
     @staticmethod
-    def exec(datasource=None, table=None, output=None, interaction=True, skip_report=False, dbt_command='',
-             skip_recommend=False, report_dir: str = None):
+    def exec(datasource=None, table=None, output=None, skip_report=False, dbt_state_dir: str = None,
+             report_dir: str = None):
         console = Console()
 
         raise_exception_when_directory_not_writable(output)
@@ -629,29 +584,47 @@ class Runner():
             console.print('\n\n[bold red]ERROR:[/bold red] Stop profiling, please fix the syntax errors above.')
             return 1
 
-        default_schema = ds.credential.get('schema')
-
         dbt_config = ds.args.get('dbt')
-        dbt_adapter = DbtAdapter(dbt_config)
-        if dbt_config and not dbt_adapter.is_ready():
-            raise dbt_adapter.get_error()
 
-        tables = None
-        if table:
-            tables = [table]
-
-        dbt_test_results = None
-        dbt_test_results_compatible = None
-        if dbt_command in ['build', 'test'] and dbt_adapter.is_ready():
-            dbt_adapter.set_dbt_command(dbt_command)
-            dbt_test_results, dbt_test_results_compatible = dbt_adapter.run_dbt_command(table, default_schema)
+        if dbt_config and not dbtutil.is_ready(dbt_config):
+            console.log('[bold red]ERROR:[/bold red] DBT configuration is not completed, please check the config.yml')
+            return 1
 
         console.rule('Profiling')
         run_id = uuid.uuid4().hex
         created_at = datetime.utcnow()
         engine = ds.create_engine()
+        default_schema = ds.credential.get('schema')
+
+        if default_schema is None and ds.type_name == 'bigquery':
+            default_schema = ds.credential.get('dataset')
+
+        if default_schema is None:
+            inspector = inspect(engine)
+            default_schema = inspector.default_schema_name
+
+        tables = None
+        dbt_test_results = None
+        dbt_test_results_compatible = None
+        if dbt_state_dir:
+            if not dbtutil.is_dbt_state_ready(dbt_state_dir):
+                console.print(
+                    f"[bold red]Error:[/bold red] No available 'manifest.json' or 'run_results.json' under '{dbt_state_dir}'")
+                return 1
+
+            includes = dbtutil.get_dbt_state_candidate(dbt_state_dir, default_schema)
+
+            if configuration.includes is not None:
+                # intersect 'includes' and 'configuration.includes'
+                includes = [include for include in includes if include in configuration.includes]
+
+            configuration.includes = includes
+
+            dbt_test_results, dbt_test_results_compatible = dbtutil.get_dbt_state_tests_result(dbt_state_dir,
+                                                                                               default_schema)
 
         if table:
+            tables = [table]
             # cli --table is specified, no inclusion and exclusion applied
             configuration.includes = None
             configuration.excludes = None
@@ -668,8 +641,8 @@ class Runner():
             raise Exception(f'Profiler Exception: {type(e).__name__}(\'{e}\')')
 
         # TODO: refactor input unused arguments
-        assertion_results, assertion_exceptions = _execute_assertions(console, engine, ds.name, interaction, output,
-                                                                      profiler_result, created_at, skip_recommend)
+        assertion_results, assertion_exceptions = _execute_assertions(console, engine, ds.name, output,
+                                                                      profiler_result, created_at)
 
         run_result['tests'] = []
         if assertion_results or dbt_test_results:
@@ -698,8 +671,12 @@ class Runner():
         _show_summary(run_result, assertion_results, assertion_exceptions, dbt_test_results)
         _show_recommended_assertion_notice_message(console, assertion_results)
 
-        if dbt_adapter.is_ready():
-            dbt_adapter.append_descriptions(run_result, default_schema)
+        if dbt_state_dir:
+            if not dbtutil.is_dbt_state_ready(dbt_state_dir):
+                console.print(
+                    f"[bold red]Error:[/bold red] No available 'manifest.json' or 'run_results.json' under '{dbt_state_dir}'")
+                return 1
+            dbtutil.append_descriptions(run_result, dbt_state_dir, default_schema)
         _append_descriptions_from_assertion(run_result)
 
         run_result['id'] = run_id
@@ -719,7 +696,7 @@ class Runner():
         if skip_report:
             console.print(f'Results saved to {output if output else output_path}')
 
-        _analyse_and_log_run_event(run_result, assertion_results, dbt_test_results, dbt_command)
+        _analyse_and_log_run_event(run_result, assertion_results, dbt_test_results)
 
         if not _check_test_status(assertion_results, assertion_exceptions, dbt_test_results):
             return EC_ERR_TEST_FAILED
